@@ -1,4 +1,4 @@
 from .form import Form
-from .fields import (CharField, IntegerField, BooleanField,
+from .fields import (StringField, IntegerField, BooleanField,
                      DateField,ChoiceField,MultipleChoiceField,FloatField,DateTimeField,EmailField,
                      SlugField,TextAreaField,CKEditor)
\ No newline at end of file
