@@ -1,8 +1,9 @@
 from valley.declarative import DeclaredVars as DV, \
     DeclarativeVariablesMetaclass as DVM
 from valley.schema import BaseSchema
-from valley.utils import import_util
+
 from .fields import BaseField
+from .utils import temp_env
 
 
 class DeclaredVars(DV):
@@ -17,7 +18,7 @@ class BaseForm(BaseSchema):
     """
     Base class for all Formy form classes.
     """
-    _template = 'formy.templates.ul_template'
+    _template = 'formy/form/ul.html'
     BUILTIN_DOC_ATTRS = []
     _create_error_dict = True
 
@@ -27,16 +28,16 @@ class BaseForm(BaseSchema):
             field.value = self._data.get(k)
             yield field
 
-    def render(self,include_submit=True):
-        template = import_util(self._template)
-        return template.render(form=self,include_submit=include_submit)
+    def render(self, include_submit=True):
+        return temp_env.get_template(self._template).render(
+            form=self, include_submit=include_submit)
 
     def render_static_assets(self):
         static_assets = []
         for field in self:
             static_assets.extend(field.static_assets)
-        return ''.join(static_assets)
+        return ''.join(set(static_assets))
 
 
 class Form(BaseForm, metaclass=DeclarativeVariablesMetaclass):
-    pass
\ No newline at end of file
+    pass
